# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/load_balancer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.apploadbalancer.v1 import logging_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_logging__pb2
from yandex.cloud.apploadbalancer.v1 import target_group_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/apploadbalancer/v1/load_balancer.proto',
  package='yandex.cloud.apploadbalancer.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3yandex/cloud/apploadbalancer/v1/load_balancer.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a-yandex/cloud/apploadbalancer/v1/logging.proto\x1a\x32yandex/cloud/apploadbalancer/v1/target_group.proto\"\xa7\x06\n\x0cLoadBalancer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12I\n\x06labels\x18\x05 \x03(\x0b\x32\x39.yandex.cloud.apploadbalancer.v1.LoadBalancer.LabelsEntry\x12\x44\n\x06status\x18\x06 \x01(\x0e\x32\x34.yandex.cloud.apploadbalancer.v1.LoadBalancer.Status\x12\x11\n\tregion_id\x18\x07 \x01(\t\x12\x12\n\nnetwork_id\x18\x08 \x01(\t\x12<\n\tlisteners\x18\t \x03(\x0b\x32).yandex.cloud.apploadbalancer.v1.Listener\x12L\n\x11\x61llocation_policy\x18\n \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.AllocationPolicy\x12\x14\n\x0clog_group_id\x18\x0b \x01(\t\x12\x1a\n\x12security_group_ids\x18\x0c \x03(\t\x12.\n\ncreated_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12K\n\x11\x61uto_scale_policy\x18\x0e \x01(\x0b\x32\x30.yandex.cloud.apploadbalancer.v1.AutoScalePolicy\x12@\n\x0blog_options\x18\x0f \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"q\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0c\n\x08STARTING\x10\x02\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\"\x9f\x02\n\x07\x41\x64\x64ress\x12U\n\x15\x65xternal_ipv4_address\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.ExternalIpv4AddressH\x00\x12U\n\x15internal_ipv4_address\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.InternalIpv4AddressH\x00\x12U\n\x15\x65xternal_ipv6_address\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.ExternalIpv6AddressH\x00\x42\x0f\n\x07\x61\x64\x64ress\x12\x04\xc0\xc1\x31\x01\"&\n\x13\x45xternalIpv4Address\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"9\n\x13InternalIpv4Address\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\"&\n\x13\x45xternalIpv6Address\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"M\n\x08Location\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\x12\x17\n\x0f\x64isable_traffic\x18\x03 \x01(\x08\"]\n\x10\x41llocationPolicy\x12I\n\tlocations\x18\x01 \x03(\x0b\x32).yandex.cloud.apploadbalancer.v1.LocationB\x0b\x82\xc8\x31\x03>=1\x90\xc8\x31\x01\"\xad\x02\n\x08Listener\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12<\n\tendpoints\x18\x02 \x03(\x0b\x32).yandex.cloud.apploadbalancer.v1.Endpoint\x12=\n\x04http\x18\x03 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.HttpListenerH\x00\x12;\n\x03tls\x18\x04 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.TlsListenerH\x00\x12\x41\n\x06stream\x18\x05 \x01(\x0b\x32/.yandex.cloud.apploadbalancer.v1.StreamListenerH\x00\x42\x10\n\x08listener\x12\x04\xc0\xc1\x31\x01\"q\n\x08\x45ndpoint\x12\x43\n\taddresses\x18\x01 \x03(\x0b\x32(.yandex.cloud.apploadbalancer.v1.AddressB\x06\x82\xc8\x31\x02>0\x12 \n\x05ports\x18\x02 \x03(\x03\x42\x11\x82\xc8\x31\x02>0\xfa\xc7\x31\x07\x31-65535\"\x8c\x01\n\x0cHttpListener\x12=\n\x07handler\x18\x01 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HttpHandler\x12=\n\tredirects\x18\x02 \x01(\x0b\x32*.yandex.cloud.apploadbalancer.v1.Redirects\"\x9a\x01\n\x0bTlsListener\x12J\n\x0f\x64\x65\x66\x61ult_handler\x18\x01 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.TlsHandlerB\x04\xe8\xc7\x31\x01\x12?\n\x0csni_handlers\x18\x02 \x03(\x0b\x32).yandex.cloud.apploadbalancer.v1.SniMatch\"W\n\x0eStreamListener\x12\x45\n\x07handler\x18\x01 \x01(\x0b\x32..yandex.cloud.apploadbalancer.v1.StreamHandlerB\x04\xe8\xc7\x31\x01\".\n\x0cHttp2Options\x12\x1e\n\x16max_concurrent_streams\x18\x01 \x01(\x03\"/\n\rStreamHandler\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x9a\x01\n\x0bHttpHandler\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x46\n\rhttp2_options\x18\x02 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.Http2OptionsH\x00\x12\x16\n\x0c\x61llow_http10\x18\x03 \x01(\x08H\x00\x42\x13\n\x11protocol_settings\"\"\n\tRedirects\x12\x15\n\rhttp_to_https\x18\x01 \x01(\x08\"\x80\x01\n\x08SniMatch\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1c\n\x0cserver_names\x18\x02 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x42\n\x07handler\x18\x03 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.TlsHandlerB\x04\xe8\xc7\x31\x01\"\xce\x01\n\nTlsHandler\x12\x44\n\x0chttp_handler\x18\x02 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HttpHandlerH\x00\x12H\n\x0estream_handler\x18\x04 \x01(\x0b\x32..yandex.cloud.apploadbalancer.v1.StreamHandlerH\x00\x12\x1f\n\x0f\x63\x65rtificate_ids\x18\x03 \x03(\tB\x06\x82\xc8\x31\x02>0B\x0f\n\x07handler\x12\x04\xc0\xc1\x31\x01\"\x8c\x04\n\x0bTargetState\x12N\n\x06status\x18\x01 \x01(\x0b\x32>.yandex.cloud.apploadbalancer.v1.TargetState.HealthcheckStatus\x12=\n\x06target\x18\x02 \x01(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.TargetB\x04\xe8\xc7\x31\x01\x1an\n\x11HealthcheckStatus\x12Y\n\rzone_statuses\x18\x01 \x03(\x0b\x32\x42.yandex.cloud.apploadbalancer.v1.TargetState.ZoneHealthcheckStatus\x1a\x8d\x01\n\x15ZoneHealthcheckStatus\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x43\n\x06status\x18\x02 \x01(\x0e\x32\x33.yandex.cloud.apploadbalancer.v1.TargetState.Status\x12\x18\n\x10\x66\x61iled_active_hc\x18\x03 \x01(\x08\"n\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07HEALTHY\x10\x01\x12\x15\n\x11PARTIALLY_HEALTHY\x10\x02\x12\r\n\tUNHEALTHY\x10\x03\x12\x0c\n\x08\x44RAINING\x10\x04\x12\x0b\n\x07TIMEOUT\x10\x05\"R\n\x0f\x41utoScalePolicy\x12!\n\rmin_zone_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1c\n\x08max_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000Bz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_logging__pb2.DESCRIPTOR,yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2.DESCRIPTOR,])



_LOADBALANCER_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=946,
  serialized_end=1059,
)
_sym_db.RegisterEnumDescriptor(_LOADBALANCER_STATUS)

_TARGETSTATE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.apploadbalancer.v1.TargetState.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEALTHY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTIALLY_HEALTHY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNHEALTHY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRAINING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3517,
  serialized_end=3627,
)
_sym_db.RegisterEnumDescriptor(_TARGETSTATE_STATUS)


_LOADBALANCER_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=899,
  serialized_end=944,
)

_LOADBALANCER = _descriptor.Descriptor(
  name='LoadBalancer',
  full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.folder_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region_id', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.region_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.network_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listeners', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.listeners', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocation_policy', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.allocation_policy', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.log_group_id', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_ids', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.security_group_ids', index=11,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.created_at', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_scale_policy', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.auto_scale_policy', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_options', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancer.log_options', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LOADBALANCER_LABELSENTRY, ],
  enum_types=[
    _LOADBALANCER_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=1059,
)


_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='yandex.cloud.apploadbalancer.v1.Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_ipv4_address', full_name='yandex.cloud.apploadbalancer.v1.Address.external_ipv4_address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_ipv4_address', full_name='yandex.cloud.apploadbalancer.v1.Address.internal_ipv4_address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_ipv6_address', full_name='yandex.cloud.apploadbalancer.v1.Address.external_ipv6_address', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address', full_name='yandex.cloud.apploadbalancer.v1.Address.address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=1062,
  serialized_end=1349,
)


_EXTERNALIPV4ADDRESS = _descriptor.Descriptor(
  name='ExternalIpv4Address',
  full_name='yandex.cloud.apploadbalancer.v1.ExternalIpv4Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.apploadbalancer.v1.ExternalIpv4Address.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1351,
  serialized_end=1389,
)


_INTERNALIPV4ADDRESS = _descriptor.Descriptor(
  name='InternalIpv4Address',
  full_name='yandex.cloud.apploadbalancer.v1.InternalIpv4Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.apploadbalancer.v1.InternalIpv4Address.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.apploadbalancer.v1.InternalIpv4Address.subnet_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1391,
  serialized_end=1448,
)


_EXTERNALIPV6ADDRESS = _descriptor.Descriptor(
  name='ExternalIpv6Address',
  full_name='yandex.cloud.apploadbalancer.v1.ExternalIpv6Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.apploadbalancer.v1.ExternalIpv6Address.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1450,
  serialized_end=1488,
)


_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='yandex.cloud.apploadbalancer.v1.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.apploadbalancer.v1.Location.zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.apploadbalancer.v1.Location.subnet_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_traffic', full_name='yandex.cloud.apploadbalancer.v1.Location.disable_traffic', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1490,
  serialized_end=1567,
)


_ALLOCATIONPOLICY = _descriptor.Descriptor(
  name='AllocationPolicy',
  full_name='yandex.cloud.apploadbalancer.v1.AllocationPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locations', full_name='yandex.cloud.apploadbalancer.v1.AllocationPolicy.locations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003>=1\220\3101\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1569,
  serialized_end=1662,
)


_LISTENER = _descriptor.Descriptor(
  name='Listener',
  full_name='yandex.cloud.apploadbalancer.v1.Listener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.Listener.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoints', full_name='yandex.cloud.apploadbalancer.v1.Listener.endpoints', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http', full_name='yandex.cloud.apploadbalancer.v1.Listener.http', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls', full_name='yandex.cloud.apploadbalancer.v1.Listener.tls', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream', full_name='yandex.cloud.apploadbalancer.v1.Listener.stream', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='listener', full_name='yandex.cloud.apploadbalancer.v1.Listener.listener',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=1665,
  serialized_end=1966,
)


_ENDPOINT = _descriptor.Descriptor(
  name='Endpoint',
  full_name='yandex.cloud.apploadbalancer.v1.Endpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='yandex.cloud.apploadbalancer.v1.Endpoint.addresses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ports', full_name='yandex.cloud.apploadbalancer.v1.Endpoint.ports', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0\372\3071\0071-65535', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1968,
  serialized_end=2081,
)


_HTTPLISTENER = _descriptor.Descriptor(
  name='HttpListener',
  full_name='yandex.cloud.apploadbalancer.v1.HttpListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='handler', full_name='yandex.cloud.apploadbalancer.v1.HttpListener.handler', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirects', full_name='yandex.cloud.apploadbalancer.v1.HttpListener.redirects', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2084,
  serialized_end=2224,
)


_TLSLISTENER = _descriptor.Descriptor(
  name='TlsListener',
  full_name='yandex.cloud.apploadbalancer.v1.TlsListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_handler', full_name='yandex.cloud.apploadbalancer.v1.TlsListener.default_handler', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sni_handlers', full_name='yandex.cloud.apploadbalancer.v1.TlsListener.sni_handlers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2227,
  serialized_end=2381,
)


_STREAMLISTENER = _descriptor.Descriptor(
  name='StreamListener',
  full_name='yandex.cloud.apploadbalancer.v1.StreamListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='handler', full_name='yandex.cloud.apploadbalancer.v1.StreamListener.handler', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2383,
  serialized_end=2470,
)


_HTTP2OPTIONS = _descriptor.Descriptor(
  name='Http2Options',
  full_name='yandex.cloud.apploadbalancer.v1.Http2Options',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_concurrent_streams', full_name='yandex.cloud.apploadbalancer.v1.Http2Options.max_concurrent_streams', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2472,
  serialized_end=2518,
)


_STREAMHANDLER = _descriptor.Descriptor(
  name='StreamHandler',
  full_name='yandex.cloud.apploadbalancer.v1.StreamHandler',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.StreamHandler.backend_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2520,
  serialized_end=2567,
)


_HTTPHANDLER = _descriptor.Descriptor(
  name='HttpHandler',
  full_name='yandex.cloud.apploadbalancer.v1.HttpHandler',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.HttpHandler.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http2_options', full_name='yandex.cloud.apploadbalancer.v1.HttpHandler.http2_options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_http10', full_name='yandex.cloud.apploadbalancer.v1.HttpHandler.allow_http10', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='protocol_settings', full_name='yandex.cloud.apploadbalancer.v1.HttpHandler.protocol_settings',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2570,
  serialized_end=2724,
)


_REDIRECTS = _descriptor.Descriptor(
  name='Redirects',
  full_name='yandex.cloud.apploadbalancer.v1.Redirects',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_to_https', full_name='yandex.cloud.apploadbalancer.v1.Redirects.http_to_https', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2726,
  serialized_end=2760,
)


_SNIMATCH = _descriptor.Descriptor(
  name='SniMatch',
  full_name='yandex.cloud.apploadbalancer.v1.SniMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.SniMatch.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_names', full_name='yandex.cloud.apploadbalancer.v1.SniMatch.server_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='handler', full_name='yandex.cloud.apploadbalancer.v1.SniMatch.handler', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2763,
  serialized_end=2891,
)


_TLSHANDLER = _descriptor.Descriptor(
  name='TlsHandler',
  full_name='yandex.cloud.apploadbalancer.v1.TlsHandler',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_handler', full_name='yandex.cloud.apploadbalancer.v1.TlsHandler.http_handler', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_handler', full_name='yandex.cloud.apploadbalancer.v1.TlsHandler.stream_handler', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate_ids', full_name='yandex.cloud.apploadbalancer.v1.TlsHandler.certificate_ids', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='handler', full_name='yandex.cloud.apploadbalancer.v1.TlsHandler.handler',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=2894,
  serialized_end=3100,
)


_TARGETSTATE_HEALTHCHECKSTATUS = _descriptor.Descriptor(
  name='HealthcheckStatus',
  full_name='yandex.cloud.apploadbalancer.v1.TargetState.HealthcheckStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='zone_statuses', full_name='yandex.cloud.apploadbalancer.v1.TargetState.HealthcheckStatus.zone_statuses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3261,
  serialized_end=3371,
)

_TARGETSTATE_ZONEHEALTHCHECKSTATUS = _descriptor.Descriptor(
  name='ZoneHealthcheckStatus',
  full_name='yandex.cloud.apploadbalancer.v1.TargetState.ZoneHealthcheckStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.apploadbalancer.v1.TargetState.ZoneHealthcheckStatus.zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.apploadbalancer.v1.TargetState.ZoneHealthcheckStatus.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failed_active_hc', full_name='yandex.cloud.apploadbalancer.v1.TargetState.ZoneHealthcheckStatus.failed_active_hc', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3374,
  serialized_end=3515,
)

_TARGETSTATE = _descriptor.Descriptor(
  name='TargetState',
  full_name='yandex.cloud.apploadbalancer.v1.TargetState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.apploadbalancer.v1.TargetState.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='yandex.cloud.apploadbalancer.v1.TargetState.target', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TARGETSTATE_HEALTHCHECKSTATUS, _TARGETSTATE_ZONEHEALTHCHECKSTATUS, ],
  enum_types=[
    _TARGETSTATE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3103,
  serialized_end=3627,
)


_AUTOSCALEPOLICY = _descriptor.Descriptor(
  name='AutoScalePolicy',
  full_name='yandex.cloud.apploadbalancer.v1.AutoScalePolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_zone_size', full_name='yandex.cloud.apploadbalancer.v1.AutoScalePolicy.min_zone_size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_size', full_name='yandex.cloud.apploadbalancer.v1.AutoScalePolicy.max_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3629,
  serialized_end=3711,
)

_LOADBALANCER_LABELSENTRY.containing_type = _LOADBALANCER
_LOADBALANCER.fields_by_name['labels'].message_type = _LOADBALANCER_LABELSENTRY
_LOADBALANCER.fields_by_name['status'].enum_type = _LOADBALANCER_STATUS
_LOADBALANCER.fields_by_name['listeners'].message_type = _LISTENER
_LOADBALANCER.fields_by_name['allocation_policy'].message_type = _ALLOCATIONPOLICY
_LOADBALANCER.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOADBALANCER.fields_by_name['auto_scale_policy'].message_type = _AUTOSCALEPOLICY
_LOADBALANCER.fields_by_name['log_options'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_logging__pb2._LOGOPTIONS
_LOADBALANCER_STATUS.containing_type = _LOADBALANCER
_ADDRESS.fields_by_name['external_ipv4_address'].message_type = _EXTERNALIPV4ADDRESS
_ADDRESS.fields_by_name['internal_ipv4_address'].message_type = _INTERNALIPV4ADDRESS
_ADDRESS.fields_by_name['external_ipv6_address'].message_type = _EXTERNALIPV6ADDRESS
_ADDRESS.oneofs_by_name['address'].fields.append(
  _ADDRESS.fields_by_name['external_ipv4_address'])
_ADDRESS.fields_by_name['external_ipv4_address'].containing_oneof = _ADDRESS.oneofs_by_name['address']
_ADDRESS.oneofs_by_name['address'].fields.append(
  _ADDRESS.fields_by_name['internal_ipv4_address'])
_ADDRESS.fields_by_name['internal_ipv4_address'].containing_oneof = _ADDRESS.oneofs_by_name['address']
_ADDRESS.oneofs_by_name['address'].fields.append(
  _ADDRESS.fields_by_name['external_ipv6_address'])
_ADDRESS.fields_by_name['external_ipv6_address'].containing_oneof = _ADDRESS.oneofs_by_name['address']
_ALLOCATIONPOLICY.fields_by_name['locations'].message_type = _LOCATION
_LISTENER.fields_by_name['endpoints'].message_type = _ENDPOINT
_LISTENER.fields_by_name['http'].message_type = _HTTPLISTENER
_LISTENER.fields_by_name['tls'].message_type = _TLSLISTENER
_LISTENER.fields_by_name['stream'].message_type = _STREAMLISTENER
_LISTENER.oneofs_by_name['listener'].fields.append(
  _LISTENER.fields_by_name['http'])
_LISTENER.fields_by_name['http'].containing_oneof = _LISTENER.oneofs_by_name['listener']
_LISTENER.oneofs_by_name['listener'].fields.append(
  _LISTENER.fields_by_name['tls'])
_LISTENER.fields_by_name['tls'].containing_oneof = _LISTENER.oneofs_by_name['listener']
_LISTENER.oneofs_by_name['listener'].fields.append(
  _LISTENER.fields_by_name['stream'])
_LISTENER.fields_by_name['stream'].containing_oneof = _LISTENER.oneofs_by_name['listener']
_ENDPOINT.fields_by_name['addresses'].message_type = _ADDRESS
_HTTPLISTENER.fields_by_name['handler'].message_type = _HTTPHANDLER
_HTTPLISTENER.fields_by_name['redirects'].message_type = _REDIRECTS
_TLSLISTENER.fields_by_name['default_handler'].message_type = _TLSHANDLER
_TLSLISTENER.fields_by_name['sni_handlers'].message_type = _SNIMATCH
_STREAMLISTENER.fields_by_name['handler'].message_type = _STREAMHANDLER
_HTTPHANDLER.fields_by_name['http2_options'].message_type = _HTTP2OPTIONS
_HTTPHANDLER.oneofs_by_name['protocol_settings'].fields.append(
  _HTTPHANDLER.fields_by_name['http2_options'])
_HTTPHANDLER.fields_by_name['http2_options'].containing_oneof = _HTTPHANDLER.oneofs_by_name['protocol_settings']
_HTTPHANDLER.oneofs_by_name['protocol_settings'].fields.append(
  _HTTPHANDLER.fields_by_name['allow_http10'])
_HTTPHANDLER.fields_by_name['allow_http10'].containing_oneof = _HTTPHANDLER.oneofs_by_name['protocol_settings']
_SNIMATCH.fields_by_name['handler'].message_type = _TLSHANDLER
_TLSHANDLER.fields_by_name['http_handler'].message_type = _HTTPHANDLER
_TLSHANDLER.fields_by_name['stream_handler'].message_type = _STREAMHANDLER
_TLSHANDLER.oneofs_by_name['handler'].fields.append(
  _TLSHANDLER.fields_by_name['http_handler'])
_TLSHANDLER.fields_by_name['http_handler'].containing_oneof = _TLSHANDLER.oneofs_by_name['handler']
_TLSHANDLER.oneofs_by_name['handler'].fields.append(
  _TLSHANDLER.fields_by_name['stream_handler'])
_TLSHANDLER.fields_by_name['stream_handler'].containing_oneof = _TLSHANDLER.oneofs_by_name['handler']
_TARGETSTATE_HEALTHCHECKSTATUS.fields_by_name['zone_statuses'].message_type = _TARGETSTATE_ZONEHEALTHCHECKSTATUS
_TARGETSTATE_HEALTHCHECKSTATUS.containing_type = _TARGETSTATE
_TARGETSTATE_ZONEHEALTHCHECKSTATUS.fields_by_name['status'].enum_type = _TARGETSTATE_STATUS
_TARGETSTATE_ZONEHEALTHCHECKSTATUS.containing_type = _TARGETSTATE
_TARGETSTATE.fields_by_name['status'].message_type = _TARGETSTATE_HEALTHCHECKSTATUS
_TARGETSTATE.fields_by_name['target'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2._TARGET
_TARGETSTATE_STATUS.containing_type = _TARGETSTATE
DESCRIPTOR.message_types_by_name['LoadBalancer'] = _LOADBALANCER
DESCRIPTOR.message_types_by_name['Address'] = _ADDRESS
DESCRIPTOR.message_types_by_name['ExternalIpv4Address'] = _EXTERNALIPV4ADDRESS
DESCRIPTOR.message_types_by_name['InternalIpv4Address'] = _INTERNALIPV4ADDRESS
DESCRIPTOR.message_types_by_name['ExternalIpv6Address'] = _EXTERNALIPV6ADDRESS
DESCRIPTOR.message_types_by_name['Location'] = _LOCATION
DESCRIPTOR.message_types_by_name['AllocationPolicy'] = _ALLOCATIONPOLICY
DESCRIPTOR.message_types_by_name['Listener'] = _LISTENER
DESCRIPTOR.message_types_by_name['Endpoint'] = _ENDPOINT
DESCRIPTOR.message_types_by_name['HttpListener'] = _HTTPLISTENER
DESCRIPTOR.message_types_by_name['TlsListener'] = _TLSLISTENER
DESCRIPTOR.message_types_by_name['StreamListener'] = _STREAMLISTENER
DESCRIPTOR.message_types_by_name['Http2Options'] = _HTTP2OPTIONS
DESCRIPTOR.message_types_by_name['StreamHandler'] = _STREAMHANDLER
DESCRIPTOR.message_types_by_name['HttpHandler'] = _HTTPHANDLER
DESCRIPTOR.message_types_by_name['Redirects'] = _REDIRECTS
DESCRIPTOR.message_types_by_name['SniMatch'] = _SNIMATCH
DESCRIPTOR.message_types_by_name['TlsHandler'] = _TLSHANDLER
DESCRIPTOR.message_types_by_name['TargetState'] = _TARGETSTATE
DESCRIPTOR.message_types_by_name['AutoScalePolicy'] = _AUTOSCALEPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LoadBalancer = _reflection.GeneratedProtocolMessageType('LoadBalancer', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LOADBALANCER_LABELSENTRY,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.LoadBalancer.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LOADBALANCER,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.LoadBalancer)
  })
_sym_db.RegisterMessage(LoadBalancer)
_sym_db.RegisterMessage(LoadBalancer.LabelsEntry)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.Address)
  })
_sym_db.RegisterMessage(Address)

ExternalIpv4Address = _reflection.GeneratedProtocolMessageType('ExternalIpv4Address', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALIPV4ADDRESS,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ExternalIpv4Address)
  })
_sym_db.RegisterMessage(ExternalIpv4Address)

InternalIpv4Address = _reflection.GeneratedProtocolMessageType('InternalIpv4Address', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALIPV4ADDRESS,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.InternalIpv4Address)
  })
_sym_db.RegisterMessage(InternalIpv4Address)

ExternalIpv6Address = _reflection.GeneratedProtocolMessageType('ExternalIpv6Address', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALIPV6ADDRESS,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ExternalIpv6Address)
  })
_sym_db.RegisterMessage(ExternalIpv6Address)

Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
  'DESCRIPTOR' : _LOCATION,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.Location)
  })
_sym_db.RegisterMessage(Location)

AllocationPolicy = _reflection.GeneratedProtocolMessageType('AllocationPolicy', (_message.Message,), {
  'DESCRIPTOR' : _ALLOCATIONPOLICY,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.AllocationPolicy)
  })
_sym_db.RegisterMessage(AllocationPolicy)

Listener = _reflection.GeneratedProtocolMessageType('Listener', (_message.Message,), {
  'DESCRIPTOR' : _LISTENER,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.Listener)
  })
_sym_db.RegisterMessage(Listener)

Endpoint = _reflection.GeneratedProtocolMessageType('Endpoint', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINT,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.Endpoint)
  })
_sym_db.RegisterMessage(Endpoint)

HttpListener = _reflection.GeneratedProtocolMessageType('HttpListener', (_message.Message,), {
  'DESCRIPTOR' : _HTTPLISTENER,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.HttpListener)
  })
_sym_db.RegisterMessage(HttpListener)

TlsListener = _reflection.GeneratedProtocolMessageType('TlsListener', (_message.Message,), {
  'DESCRIPTOR' : _TLSLISTENER,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.TlsListener)
  })
_sym_db.RegisterMessage(TlsListener)

StreamListener = _reflection.GeneratedProtocolMessageType('StreamListener', (_message.Message,), {
  'DESCRIPTOR' : _STREAMLISTENER,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.StreamListener)
  })
_sym_db.RegisterMessage(StreamListener)

Http2Options = _reflection.GeneratedProtocolMessageType('Http2Options', (_message.Message,), {
  'DESCRIPTOR' : _HTTP2OPTIONS,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.Http2Options)
  })
_sym_db.RegisterMessage(Http2Options)

StreamHandler = _reflection.GeneratedProtocolMessageType('StreamHandler', (_message.Message,), {
  'DESCRIPTOR' : _STREAMHANDLER,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.StreamHandler)
  })
_sym_db.RegisterMessage(StreamHandler)

HttpHandler = _reflection.GeneratedProtocolMessageType('HttpHandler', (_message.Message,), {
  'DESCRIPTOR' : _HTTPHANDLER,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.HttpHandler)
  })
_sym_db.RegisterMessage(HttpHandler)

Redirects = _reflection.GeneratedProtocolMessageType('Redirects', (_message.Message,), {
  'DESCRIPTOR' : _REDIRECTS,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.Redirects)
  })
_sym_db.RegisterMessage(Redirects)

SniMatch = _reflection.GeneratedProtocolMessageType('SniMatch', (_message.Message,), {
  'DESCRIPTOR' : _SNIMATCH,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.SniMatch)
  })
_sym_db.RegisterMessage(SniMatch)

TlsHandler = _reflection.GeneratedProtocolMessageType('TlsHandler', (_message.Message,), {
  'DESCRIPTOR' : _TLSHANDLER,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.TlsHandler)
  })
_sym_db.RegisterMessage(TlsHandler)

TargetState = _reflection.GeneratedProtocolMessageType('TargetState', (_message.Message,), {

  'HealthcheckStatus' : _reflection.GeneratedProtocolMessageType('HealthcheckStatus', (_message.Message,), {
    'DESCRIPTOR' : _TARGETSTATE_HEALTHCHECKSTATUS,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.TargetState.HealthcheckStatus)
    })
  ,

  'ZoneHealthcheckStatus' : _reflection.GeneratedProtocolMessageType('ZoneHealthcheckStatus', (_message.Message,), {
    'DESCRIPTOR' : _TARGETSTATE_ZONEHEALTHCHECKSTATUS,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.TargetState.ZoneHealthcheckStatus)
    })
  ,
  'DESCRIPTOR' : _TARGETSTATE,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.TargetState)
  })
_sym_db.RegisterMessage(TargetState)
_sym_db.RegisterMessage(TargetState.HealthcheckStatus)
_sym_db.RegisterMessage(TargetState.ZoneHealthcheckStatus)

AutoScalePolicy = _reflection.GeneratedProtocolMessageType('AutoScalePolicy', (_message.Message,), {
  'DESCRIPTOR' : _AUTOSCALEPOLICY,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.AutoScalePolicy)
  })
_sym_db.RegisterMessage(AutoScalePolicy)


DESCRIPTOR._options = None
_LOADBALANCER_LABELSENTRY._options = None
_ADDRESS.oneofs_by_name['address']._options = None
_LOCATION.fields_by_name['zone_id']._options = None
_ALLOCATIONPOLICY.fields_by_name['locations']._options = None
_LISTENER.oneofs_by_name['listener']._options = None
_LISTENER.fields_by_name['name']._options = None
_ENDPOINT.fields_by_name['addresses']._options = None
_ENDPOINT.fields_by_name['ports']._options = None
_TLSLISTENER.fields_by_name['default_handler']._options = None
_STREAMLISTENER.fields_by_name['handler']._options = None
_STREAMHANDLER.fields_by_name['backend_group_id']._options = None
_SNIMATCH.fields_by_name['name']._options = None
_SNIMATCH.fields_by_name['server_names']._options = None
_SNIMATCH.fields_by_name['handler']._options = None
_TLSHANDLER.oneofs_by_name['handler']._options = None
_TLSHANDLER.fields_by_name['certificate_ids']._options = None
_TARGETSTATE_ZONEHEALTHCHECKSTATUS.fields_by_name['zone_id']._options = None
_TARGETSTATE.fields_by_name['target']._options = None
_AUTOSCALEPOLICY.fields_by_name['min_zone_size']._options = None
_AUTOSCALEPOLICY.fields_by_name['max_size']._options = None
# @@protoc_insertion_point(module_scope)
