# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/snapshot_schedule.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/snapshot_schedule.proto',
  package='yandex.cloud.compute.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/yandex/cloud/compute/v1/snapshot_schedule.proto\x12\x17yandex.cloud.compute.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x87\x05\n\x10SnapshotSchedule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x45\n\x06labels\x18\x06 \x03(\x0b\x32\x35.yandex.cloud.compute.v1.SnapshotSchedule.LabelsEntry\x12@\n\x06status\x18\x07 \x01(\x0e\x32\x30.yandex.cloud.compute.v1.SnapshotSchedule.Status\x12@\n\x0fschedule_policy\x18\x08 \x01(\x0b\x32\'.yandex.cloud.compute.v1.SchedulePolicy\x12\x35\n\x10retention_period\x18\t \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12\x18\n\x0esnapshot_count\x18\n \x01(\x03H\x00\x12<\n\rsnapshot_spec\x18\x0b \x01(\x0b\x32%.yandex.cloud.compute.v1.SnapshotSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"d\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\x12\x0c\n\x08UPDATING\x10\x05\x42\x12\n\x10retention_policy\"R\n\x0eSchedulePolicy\x12,\n\x08start_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nexpression\x18\x02 \x01(\t\"\x95\x01\n\x0cSnapshotSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x41\n\x06labels\x18\x02 \x03(\x0b\x32\x31.yandex.cloud.compute.v1.SnapshotSpec.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x62\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_SNAPSHOTSCHEDULE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.compute.v1.SnapshotSchedule.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INACTIVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=669,
  serialized_end=769,
)
_sym_db.RegisterEnumDescriptor(_SNAPSHOTSCHEDULE_STATUS)


_SNAPSHOTSCHEDULE_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.SnapshotSchedule.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.SnapshotSchedule.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.SnapshotSchedule.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=667,
)

_SNAPSHOTSCHEDULE = _descriptor.Descriptor(
  name='SnapshotSchedule',
  full_name='yandex.cloud.compute.v1.SnapshotSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.compute.v1.SnapshotSchedule.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.SnapshotSchedule.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.compute.v1.SnapshotSchedule.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.SnapshotSchedule.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.SnapshotSchedule.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.SnapshotSchedule.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.compute.v1.SnapshotSchedule.status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule_policy', full_name='yandex.cloud.compute.v1.SnapshotSchedule.schedule_policy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_period', full_name='yandex.cloud.compute.v1.SnapshotSchedule.retention_period', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_count', full_name='yandex.cloud.compute.v1.SnapshotSchedule.snapshot_count', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_spec', full_name='yandex.cloud.compute.v1.SnapshotSchedule.snapshot_spec', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SNAPSHOTSCHEDULE_LABELSENTRY, ],
  enum_types=[
    _SNAPSHOTSCHEDULE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='retention_policy', full_name='yandex.cloud.compute.v1.SnapshotSchedule.retention_policy',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=142,
  serialized_end=789,
)


_SCHEDULEPOLICY = _descriptor.Descriptor(
  name='SchedulePolicy',
  full_name='yandex.cloud.compute.v1.SchedulePolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_at', full_name='yandex.cloud.compute.v1.SchedulePolicy.start_at', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expression', full_name='yandex.cloud.compute.v1.SchedulePolicy.expression', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=791,
  serialized_end=873,
)


_SNAPSHOTSPEC_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.SnapshotSpec.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.SnapshotSpec.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.SnapshotSpec.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=667,
)

_SNAPSHOTSPEC = _descriptor.Descriptor(
  name='SnapshotSpec',
  full_name='yandex.cloud.compute.v1.SnapshotSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.SnapshotSpec.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.SnapshotSpec.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SNAPSHOTSPEC_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=876,
  serialized_end=1025,
)

_SNAPSHOTSCHEDULE_LABELSENTRY.containing_type = _SNAPSHOTSCHEDULE
_SNAPSHOTSCHEDULE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SNAPSHOTSCHEDULE.fields_by_name['labels'].message_type = _SNAPSHOTSCHEDULE_LABELSENTRY
_SNAPSHOTSCHEDULE.fields_by_name['status'].enum_type = _SNAPSHOTSCHEDULE_STATUS
_SNAPSHOTSCHEDULE.fields_by_name['schedule_policy'].message_type = _SCHEDULEPOLICY
_SNAPSHOTSCHEDULE.fields_by_name['retention_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SNAPSHOTSCHEDULE.fields_by_name['snapshot_spec'].message_type = _SNAPSHOTSPEC
_SNAPSHOTSCHEDULE_STATUS.containing_type = _SNAPSHOTSCHEDULE
_SNAPSHOTSCHEDULE.oneofs_by_name['retention_policy'].fields.append(
  _SNAPSHOTSCHEDULE.fields_by_name['retention_period'])
_SNAPSHOTSCHEDULE.fields_by_name['retention_period'].containing_oneof = _SNAPSHOTSCHEDULE.oneofs_by_name['retention_policy']
_SNAPSHOTSCHEDULE.oneofs_by_name['retention_policy'].fields.append(
  _SNAPSHOTSCHEDULE.fields_by_name['snapshot_count'])
_SNAPSHOTSCHEDULE.fields_by_name['snapshot_count'].containing_oneof = _SNAPSHOTSCHEDULE.oneofs_by_name['retention_policy']
_SCHEDULEPOLICY.fields_by_name['start_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SNAPSHOTSPEC_LABELSENTRY.containing_type = _SNAPSHOTSPEC
_SNAPSHOTSPEC.fields_by_name['labels'].message_type = _SNAPSHOTSPEC_LABELSENTRY
DESCRIPTOR.message_types_by_name['SnapshotSchedule'] = _SNAPSHOTSCHEDULE
DESCRIPTOR.message_types_by_name['SchedulePolicy'] = _SCHEDULEPOLICY
DESCRIPTOR.message_types_by_name['SnapshotSpec'] = _SNAPSHOTSPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SnapshotSchedule = _reflection.GeneratedProtocolMessageType('SnapshotSchedule', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SNAPSHOTSCHEDULE_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.SnapshotSchedule.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _SNAPSHOTSCHEDULE,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.SnapshotSchedule)
  })
_sym_db.RegisterMessage(SnapshotSchedule)
_sym_db.RegisterMessage(SnapshotSchedule.LabelsEntry)

SchedulePolicy = _reflection.GeneratedProtocolMessageType('SchedulePolicy', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEPOLICY,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.SchedulePolicy)
  })
_sym_db.RegisterMessage(SchedulePolicy)

SnapshotSpec = _reflection.GeneratedProtocolMessageType('SnapshotSpec', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SNAPSHOTSPEC_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.SnapshotSpec.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _SNAPSHOTSPEC,
  '__module__' : 'yandex.cloud.compute.v1.snapshot_schedule_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.SnapshotSpec)
  })
_sym_db.RegisterMessage(SnapshotSpec)
_sym_db.RegisterMessage(SnapshotSpec.LabelsEntry)


DESCRIPTOR._options = None
_SNAPSHOTSCHEDULE_LABELSENTRY._options = None
_SNAPSHOTSPEC_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)
