# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/v1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.k8s.v1 import maintenance_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_maintenance__pb2
from yandex.cloud.k8s.v1 import version_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_version__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/k8s/v1/cluster.proto',
  package='yandex.cloud.k8s.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!yandex/cloud/k8s/v1/cluster.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a%yandex/cloud/k8s/v1/maintenance.proto\x1a!yandex/cloud/k8s/v1/version.proto\x1a\x1dyandex/cloud/validation.proto\"\xaa\x08\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x38\n\x06labels\x18\x06 \x03(\x0b\x32(.yandex.cloud.k8s.v1.Cluster.LabelsEntry\x12\x33\n\x06status\x18\x07 \x01(\x0e\x32#.yandex.cloud.k8s.v1.Cluster.Status\x12\x33\n\x06health\x18\x08 \x01(\x0e\x32#.yandex.cloud.k8s.v1.Cluster.Health\x12\x12\n\nnetwork_id\x18\t \x01(\t\x12+\n\x06master\x18\n \x01(\x0b\x32\x1b.yandex.cloud.k8s.v1.Master\x12\x45\n\x14ip_allocation_policy\x18\x0b \x01(\x0b\x32\'.yandex.cloud.k8s.v1.IPAllocationPolicy\x12(\n\x14gateway_ipv4_address\x18\x0c \x01(\tB\x08\x8a\xc8\x31\x04<=15H\x00\x12\x1a\n\x12service_account_id\x18\r \x01(\t\x12\x1f\n\x17node_service_account_id\x18\x0e \x01(\t\x12<\n\x0frelease_channel\x18\x0f \x01(\x0e\x32#.yandex.cloud.k8s.v1.ReleaseChannel\x12:\n\x0enetwork_policy\x18\x10 \x01(\x0b\x32\".yandex.cloud.k8s.v1.NetworkPolicy\x12\x36\n\x0ckms_provider\x18\x11 \x01(\x0b\x32 .yandex.cloud.k8s.v1.KMSProvider\x12\x14\n\x0clog_group_id\x18\x12 \x01(\t\x12-\n\x06\x63ilium\x18\x13 \x01(\x0b\x32\x1b.yandex.cloud.k8s.v1.CiliumH\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0f\n\x0bRECONCILING\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"<\n\x06Health\x12\x16\n\x12HEALTH_UNSPECIFIED\x10\x00\x12\x0b\n\x07HEALTHY\x10\x01\x12\r\n\tUNHEALTHY\x10\x02\x42\x12\n\x10internet_gatewayB\x18\n\x16network_implementation\"\xeb\x03\n\x06Master\x12\x38\n\x0czonal_master\x18\x01 \x01(\x0b\x32 .yandex.cloud.k8s.v1.ZonalMasterH\x00\x12>\n\x0fregional_master\x18\x07 \x01(\x0b\x32#.yandex.cloud.k8s.v1.RegionalMasterH\x00\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x37\n\tendpoints\x18\x03 \x01(\x0b\x32$.yandex.cloud.k8s.v1.MasterEndpoints\x12\x34\n\x0bmaster_auth\x18\x04 \x01(\x0b\x32\x1f.yandex.cloud.k8s.v1.MasterAuth\x12\x36\n\x0cversion_info\x18\x05 \x01(\x0b\x32 .yandex.cloud.k8s.v1.VersionInfo\x12H\n\x12maintenance_policy\x18\x06 \x01(\x0b\x32,.yandex.cloud.k8s.v1.MasterMaintenancePolicy\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12:\n\x0emaster_logging\x18\t \x01(\x0b\x32\".yandex.cloud.k8s.v1.MasterLoggingB\r\n\x0bmaster_type\",\n\nMasterAuth\x12\x1e\n\x16\x63luster_ca_certificate\x18\x01 \x01(\t\"X\n\x0bZonalMaster\x12\x0f\n\x07zone_id\x18\x01 \x01(\t\x12\x1b\n\x13internal_v4_address\x18\x02 \x01(\t\x12\x1b\n\x13\x65xternal_v4_address\x18\x03 \x01(\t\"z\n\x0eRegionalMaster\x12\x11\n\tregion_id\x18\x01 \x01(\t\x12\x1b\n\x13internal_v4_address\x18\x02 \x01(\t\x12\x1b\n\x13\x65xternal_v4_address\x18\x03 \x01(\t\x12\x1b\n\x13\x65xternal_v6_address\x18\x04 \x01(\t\"k\n\x0fMasterEndpoints\x12\x1c\n\x14internal_v4_endpoint\x18\x01 \x01(\t\x12\x1c\n\x14\x65xternal_v4_endpoint\x18\x02 \x01(\t\x12\x1c\n\x14\x65xternal_v6_endpoint\x18\x03 \x01(\t\"\xd0\x01\n\x12IPAllocationPolicy\x12\x1f\n\x17\x63luster_ipv4_cidr_block\x18\x01 \x01(\t\x12\x36\n\x18node_ipv4_cidr_mask_size\x18\x05 \x01(\x03\x42\x14\xfa\xc7\x31\x10\x30,24,25,26,27,28\x12\x1f\n\x17service_ipv4_cidr_block\x18\x02 \x01(\t\x12\x1f\n\x17\x63luster_ipv6_cidr_block\x18\x06 \x01(\t\x12\x1f\n\x17service_ipv6_cidr_block\x18\x07 \x01(\t\"s\n\x17MasterMaintenancePolicy\x12\x14\n\x0c\x61uto_upgrade\x18\x01 \x01(\x08\x12\x42\n\x12maintenance_window\x18\x02 \x01(\x0b\x32&.yandex.cloud.k8s.v1.MaintenanceWindow\"\x88\x02\n\rMasterLogging\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12;\n\x0clog_group_id\x18\x02 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12\x38\n\tfolder_id\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12\"\n\x1a\x63luster_autoscaler_enabled\x18\x05 \x01(\x08\x12\x1e\n\x16kube_apiserver_enabled\x18\x06 \x01(\x08\x12\x16\n\x0e\x65vents_enabled\x18\x07 \x01(\x08\x42\r\n\x0b\x64\x65stinationJ\x04\x08\x04\x10\x05\"\x80\x01\n\rNetworkPolicy\x12=\n\x08provider\x18\x01 \x01(\x0e\x32+.yandex.cloud.k8s.v1.NetworkPolicy.Provider\"0\n\x08Provider\x12\x18\n\x14PROVIDER_UNSPECIFIED\x10\x00\x12\n\n\x06\x43\x41LICO\x10\x01\"\x1d\n\x0bKMSProvider\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"\x80\x01\n\x06\x43ilium\x12=\n\x0crouting_mode\x18\x01 \x01(\x0e\x32\'.yandex.cloud.k8s.v1.Cilium.RoutingMode\"7\n\x0bRoutingMode\x12\x1c\n\x18ROUTING_MODE_UNSPECIFIED\x10\x00\x12\n\n\x06TUNNEL\x10\x01*U\n\x0eReleaseChannel\x12\x1f\n\x1bRELEASE_CHANNEL_UNSPECIFIED\x10\x00\x12\t\n\x05RAPID\x10\x01\x12\x0b\n\x07REGULAR\x10\x02\x12\n\n\x06STABLE\x10\x03\x42V\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_k8s_dot_v1_dot_maintenance__pb2.DESCRIPTOR,yandex_dot_cloud_dot_k8s_dot_v1_dot_version__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_RELEASECHANNEL = _descriptor.EnumDescriptor(
  name='ReleaseChannel',
  full_name='yandex.cloud.k8s.v1.ReleaseChannel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RELEASE_CHANNEL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAPID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REGULAR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STABLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3016,
  serialized_end=3101,
)
_sym_db.RegisterEnumDescriptor(_RELEASECHANNEL)

ReleaseChannel = enum_type_wrapper.EnumTypeWrapper(_RELEASECHANNEL)
RELEASE_CHANNEL_UNSPECIFIED = 0
RAPID = 1
REGULAR = 2
STABLE = 3


_CLUSTER_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.k8s.v1.Cluster.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROVISIONING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RECONCILING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1020,
  serialized_end=1155,
)
_sym_db.RegisterEnumDescriptor(_CLUSTER_STATUS)

_CLUSTER_HEALTH = _descriptor.EnumDescriptor(
  name='Health',
  full_name='yandex.cloud.k8s.v1.Cluster.Health',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HEALTH_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEALTHY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNHEALTHY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1157,
  serialized_end=1217,
)
_sym_db.RegisterEnumDescriptor(_CLUSTER_HEALTH)

_NETWORKPOLICY_PROVIDER = _descriptor.EnumDescriptor(
  name='Provider',
  full_name='yandex.cloud.k8s.v1.NetworkPolicy.Provider',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROVIDER_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CALICO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2804,
  serialized_end=2852,
)
_sym_db.RegisterEnumDescriptor(_NETWORKPOLICY_PROVIDER)

_CILIUM_ROUTINGMODE = _descriptor.EnumDescriptor(
  name='RoutingMode',
  full_name='yandex.cloud.k8s.v1.Cilium.RoutingMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ROUTING_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TUNNEL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2959,
  serialized_end=3014,
)
_sym_db.RegisterEnumDescriptor(_CILIUM_ROUTINGMODE)


_CLUSTER_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.k8s.v1.Cluster.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.k8s.v1.Cluster.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.k8s.v1.Cluster.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=972,
  serialized_end=1017,
)

_CLUSTER = _descriptor.Descriptor(
  name='Cluster',
  full_name='yandex.cloud.k8s.v1.Cluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.k8s.v1.Cluster.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.k8s.v1.Cluster.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.k8s.v1.Cluster.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.k8s.v1.Cluster.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.k8s.v1.Cluster.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.k8s.v1.Cluster.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.k8s.v1.Cluster.status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health', full_name='yandex.cloud.k8s.v1.Cluster.health', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.k8s.v1.Cluster.network_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='master', full_name='yandex.cloud.k8s.v1.Cluster.master', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_allocation_policy', full_name='yandex.cloud.k8s.v1.Cluster.ip_allocation_policy', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gateway_ipv4_address', full_name='yandex.cloud.k8s.v1.Cluster.gateway_ipv4_address', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=15', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.k8s.v1.Cluster.service_account_id', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_service_account_id', full_name='yandex.cloud.k8s.v1.Cluster.node_service_account_id', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='release_channel', full_name='yandex.cloud.k8s.v1.Cluster.release_channel', index=14,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_policy', full_name='yandex.cloud.k8s.v1.Cluster.network_policy', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kms_provider', full_name='yandex.cloud.k8s.v1.Cluster.kms_provider', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.k8s.v1.Cluster.log_group_id', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cilium', full_name='yandex.cloud.k8s.v1.Cluster.cilium', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTER_LABELSENTRY, ],
  enum_types=[
    _CLUSTER_STATUS,
    _CLUSTER_HEALTH,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='internet_gateway', full_name='yandex.cloud.k8s.v1.Cluster.internet_gateway',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='network_implementation', full_name='yandex.cloud.k8s.v1.Cluster.network_implementation',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=197,
  serialized_end=1263,
)


_MASTER = _descriptor.Descriptor(
  name='Master',
  full_name='yandex.cloud.k8s.v1.Master',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='zonal_master', full_name='yandex.cloud.k8s.v1.Master.zonal_master', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regional_master', full_name='yandex.cloud.k8s.v1.Master.regional_master', index=1,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='yandex.cloud.k8s.v1.Master.version', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoints', full_name='yandex.cloud.k8s.v1.Master.endpoints', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='master_auth', full_name='yandex.cloud.k8s.v1.Master.master_auth', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_info', full_name='yandex.cloud.k8s.v1.Master.version_info', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_policy', full_name='yandex.cloud.k8s.v1.Master.maintenance_policy', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_ids', full_name='yandex.cloud.k8s.v1.Master.security_group_ids', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='master_logging', full_name='yandex.cloud.k8s.v1.Master.master_logging', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='master_type', full_name='yandex.cloud.k8s.v1.Master.master_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1266,
  serialized_end=1757,
)


_MASTERAUTH = _descriptor.Descriptor(
  name='MasterAuth',
  full_name='yandex.cloud.k8s.v1.MasterAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_ca_certificate', full_name='yandex.cloud.k8s.v1.MasterAuth.cluster_ca_certificate', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1759,
  serialized_end=1803,
)


_ZONALMASTER = _descriptor.Descriptor(
  name='ZonalMaster',
  full_name='yandex.cloud.k8s.v1.ZonalMaster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.k8s.v1.ZonalMaster.zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_v4_address', full_name='yandex.cloud.k8s.v1.ZonalMaster.internal_v4_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_v4_address', full_name='yandex.cloud.k8s.v1.ZonalMaster.external_v4_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1805,
  serialized_end=1893,
)


_REGIONALMASTER = _descriptor.Descriptor(
  name='RegionalMaster',
  full_name='yandex.cloud.k8s.v1.RegionalMaster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='region_id', full_name='yandex.cloud.k8s.v1.RegionalMaster.region_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_v4_address', full_name='yandex.cloud.k8s.v1.RegionalMaster.internal_v4_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_v4_address', full_name='yandex.cloud.k8s.v1.RegionalMaster.external_v4_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_v6_address', full_name='yandex.cloud.k8s.v1.RegionalMaster.external_v6_address', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1895,
  serialized_end=2017,
)


_MASTERENDPOINTS = _descriptor.Descriptor(
  name='MasterEndpoints',
  full_name='yandex.cloud.k8s.v1.MasterEndpoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='internal_v4_endpoint', full_name='yandex.cloud.k8s.v1.MasterEndpoints.internal_v4_endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_v4_endpoint', full_name='yandex.cloud.k8s.v1.MasterEndpoints.external_v4_endpoint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_v6_endpoint', full_name='yandex.cloud.k8s.v1.MasterEndpoints.external_v6_endpoint', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2019,
  serialized_end=2126,
)


_IPALLOCATIONPOLICY = _descriptor.Descriptor(
  name='IPAllocationPolicy',
  full_name='yandex.cloud.k8s.v1.IPAllocationPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_ipv4_cidr_block', full_name='yandex.cloud.k8s.v1.IPAllocationPolicy.cluster_ipv4_cidr_block', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_ipv4_cidr_mask_size', full_name='yandex.cloud.k8s.v1.IPAllocationPolicy.node_ipv4_cidr_mask_size', index=1,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0200,24,25,26,27,28', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_ipv4_cidr_block', full_name='yandex.cloud.k8s.v1.IPAllocationPolicy.service_ipv4_cidr_block', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_ipv6_cidr_block', full_name='yandex.cloud.k8s.v1.IPAllocationPolicy.cluster_ipv6_cidr_block', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_ipv6_cidr_block', full_name='yandex.cloud.k8s.v1.IPAllocationPolicy.service_ipv6_cidr_block', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2129,
  serialized_end=2337,
)


_MASTERMAINTENANCEPOLICY = _descriptor.Descriptor(
  name='MasterMaintenancePolicy',
  full_name='yandex.cloud.k8s.v1.MasterMaintenancePolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auto_upgrade', full_name='yandex.cloud.k8s.v1.MasterMaintenancePolicy.auto_upgrade', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_window', full_name='yandex.cloud.k8s.v1.MasterMaintenancePolicy.maintenance_window', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2339,
  serialized_end=2454,
)


_MASTERLOGGING = _descriptor.Descriptor(
  name='MasterLogging',
  full_name='yandex.cloud.k8s.v1.MasterLogging',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.k8s.v1.MasterLogging.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.k8s.v1.MasterLogging.log_group_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.k8s.v1.MasterLogging.folder_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_autoscaler_enabled', full_name='yandex.cloud.k8s.v1.MasterLogging.cluster_autoscaler_enabled', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kube_apiserver_enabled', full_name='yandex.cloud.k8s.v1.MasterLogging.kube_apiserver_enabled', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events_enabled', full_name='yandex.cloud.k8s.v1.MasterLogging.events_enabled', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='destination', full_name='yandex.cloud.k8s.v1.MasterLogging.destination',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2457,
  serialized_end=2721,
)


_NETWORKPOLICY = _descriptor.Descriptor(
  name='NetworkPolicy',
  full_name='yandex.cloud.k8s.v1.NetworkPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider', full_name='yandex.cloud.k8s.v1.NetworkPolicy.provider', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NETWORKPOLICY_PROVIDER,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2724,
  serialized_end=2852,
)


_KMSPROVIDER = _descriptor.Descriptor(
  name='KMSProvider',
  full_name='yandex.cloud.k8s.v1.KMSProvider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.k8s.v1.KMSProvider.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2854,
  serialized_end=2883,
)


_CILIUM = _descriptor.Descriptor(
  name='Cilium',
  full_name='yandex.cloud.k8s.v1.Cilium',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='routing_mode', full_name='yandex.cloud.k8s.v1.Cilium.routing_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CILIUM_ROUTINGMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2886,
  serialized_end=3014,
)

_CLUSTER_LABELSENTRY.containing_type = _CLUSTER
_CLUSTER.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CLUSTER.fields_by_name['labels'].message_type = _CLUSTER_LABELSENTRY
_CLUSTER.fields_by_name['status'].enum_type = _CLUSTER_STATUS
_CLUSTER.fields_by_name['health'].enum_type = _CLUSTER_HEALTH
_CLUSTER.fields_by_name['master'].message_type = _MASTER
_CLUSTER.fields_by_name['ip_allocation_policy'].message_type = _IPALLOCATIONPOLICY
_CLUSTER.fields_by_name['release_channel'].enum_type = _RELEASECHANNEL
_CLUSTER.fields_by_name['network_policy'].message_type = _NETWORKPOLICY
_CLUSTER.fields_by_name['kms_provider'].message_type = _KMSPROVIDER
_CLUSTER.fields_by_name['cilium'].message_type = _CILIUM
_CLUSTER_STATUS.containing_type = _CLUSTER
_CLUSTER_HEALTH.containing_type = _CLUSTER
_CLUSTER.oneofs_by_name['internet_gateway'].fields.append(
  _CLUSTER.fields_by_name['gateway_ipv4_address'])
_CLUSTER.fields_by_name['gateway_ipv4_address'].containing_oneof = _CLUSTER.oneofs_by_name['internet_gateway']
_CLUSTER.oneofs_by_name['network_implementation'].fields.append(
  _CLUSTER.fields_by_name['cilium'])
_CLUSTER.fields_by_name['cilium'].containing_oneof = _CLUSTER.oneofs_by_name['network_implementation']
_MASTER.fields_by_name['zonal_master'].message_type = _ZONALMASTER
_MASTER.fields_by_name['regional_master'].message_type = _REGIONALMASTER
_MASTER.fields_by_name['endpoints'].message_type = _MASTERENDPOINTS
_MASTER.fields_by_name['master_auth'].message_type = _MASTERAUTH
_MASTER.fields_by_name['version_info'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_version__pb2._VERSIONINFO
_MASTER.fields_by_name['maintenance_policy'].message_type = _MASTERMAINTENANCEPOLICY
_MASTER.fields_by_name['master_logging'].message_type = _MASTERLOGGING
_MASTER.oneofs_by_name['master_type'].fields.append(
  _MASTER.fields_by_name['zonal_master'])
_MASTER.fields_by_name['zonal_master'].containing_oneof = _MASTER.oneofs_by_name['master_type']
_MASTER.oneofs_by_name['master_type'].fields.append(
  _MASTER.fields_by_name['regional_master'])
_MASTER.fields_by_name['regional_master'].containing_oneof = _MASTER.oneofs_by_name['master_type']
_MASTERMAINTENANCEPOLICY.fields_by_name['maintenance_window'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_maintenance__pb2._MAINTENANCEWINDOW
_MASTERLOGGING.oneofs_by_name['destination'].fields.append(
  _MASTERLOGGING.fields_by_name['log_group_id'])
_MASTERLOGGING.fields_by_name['log_group_id'].containing_oneof = _MASTERLOGGING.oneofs_by_name['destination']
_MASTERLOGGING.oneofs_by_name['destination'].fields.append(
  _MASTERLOGGING.fields_by_name['folder_id'])
_MASTERLOGGING.fields_by_name['folder_id'].containing_oneof = _MASTERLOGGING.oneofs_by_name['destination']
_NETWORKPOLICY.fields_by_name['provider'].enum_type = _NETWORKPOLICY_PROVIDER
_NETWORKPOLICY_PROVIDER.containing_type = _NETWORKPOLICY
_CILIUM.fields_by_name['routing_mode'].enum_type = _CILIUM_ROUTINGMODE
_CILIUM_ROUTINGMODE.containing_type = _CILIUM
DESCRIPTOR.message_types_by_name['Cluster'] = _CLUSTER
DESCRIPTOR.message_types_by_name['Master'] = _MASTER
DESCRIPTOR.message_types_by_name['MasterAuth'] = _MASTERAUTH
DESCRIPTOR.message_types_by_name['ZonalMaster'] = _ZONALMASTER
DESCRIPTOR.message_types_by_name['RegionalMaster'] = _REGIONALMASTER
DESCRIPTOR.message_types_by_name['MasterEndpoints'] = _MASTERENDPOINTS
DESCRIPTOR.message_types_by_name['IPAllocationPolicy'] = _IPALLOCATIONPOLICY
DESCRIPTOR.message_types_by_name['MasterMaintenancePolicy'] = _MASTERMAINTENANCEPOLICY
DESCRIPTOR.message_types_by_name['MasterLogging'] = _MASTERLOGGING
DESCRIPTOR.message_types_by_name['NetworkPolicy'] = _NETWORKPOLICY
DESCRIPTOR.message_types_by_name['KMSProvider'] = _KMSPROVIDER
DESCRIPTOR.message_types_by_name['Cilium'] = _CILIUM
DESCRIPTOR.enum_types_by_name['ReleaseChannel'] = _RELEASECHANNEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Cluster = _reflection.GeneratedProtocolMessageType('Cluster', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTER_LABELSENTRY,
    '__module__' : 'yandex.cloud.k8s.v1.cluster_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.Cluster.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CLUSTER,
  '__module__' : 'yandex.cloud.k8s.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.Cluster)
  })
_sym_db.RegisterMessage(Cluster)
_sym_db.RegisterMessage(Cluster.LabelsEntry)

Master = _reflection.GeneratedProtocolMessageType('Master', (_message.Message,), {
  'DESCRIPTOR' : _MASTER,
  '__module__' : 'yandex.cloud.k8s.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.Master)
  })
_sym_db.RegisterMessage(Master)

MasterAuth = _reflection.GeneratedProtocolMessageType('MasterAuth', (_message.Message,), {
  'DESCRIPTOR' : _MASTERAUTH,
  '__module__' : 'yandex.cloud.k8s.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.MasterAuth)
  })
_sym_db.RegisterMessage(MasterAuth)

ZonalMaster = _reflection.GeneratedProtocolMessageType('ZonalMaster', (_message.Message,), {
  'DESCRIPTOR' : _ZONALMASTER,
  '__module__' : 'yandex.cloud.k8s.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.ZonalMaster)
  })
_sym_db.RegisterMessage(ZonalMaster)

RegionalMaster = _reflection.GeneratedProtocolMessageType('RegionalMaster', (_message.Message,), {
  'DESCRIPTOR' : _REGIONALMASTER,
  '__module__' : 'yandex.cloud.k8s.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.RegionalMaster)
  })
_sym_db.RegisterMessage(RegionalMaster)

MasterEndpoints = _reflection.GeneratedProtocolMessageType('MasterEndpoints', (_message.Message,), {
  'DESCRIPTOR' : _MASTERENDPOINTS,
  '__module__' : 'yandex.cloud.k8s.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.MasterEndpoints)
  })
_sym_db.RegisterMessage(MasterEndpoints)

IPAllocationPolicy = _reflection.GeneratedProtocolMessageType('IPAllocationPolicy', (_message.Message,), {
  'DESCRIPTOR' : _IPALLOCATIONPOLICY,
  '__module__' : 'yandex.cloud.k8s.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.IPAllocationPolicy)
  })
_sym_db.RegisterMessage(IPAllocationPolicy)

MasterMaintenancePolicy = _reflection.GeneratedProtocolMessageType('MasterMaintenancePolicy', (_message.Message,), {
  'DESCRIPTOR' : _MASTERMAINTENANCEPOLICY,
  '__module__' : 'yandex.cloud.k8s.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.MasterMaintenancePolicy)
  })
_sym_db.RegisterMessage(MasterMaintenancePolicy)

MasterLogging = _reflection.GeneratedProtocolMessageType('MasterLogging', (_message.Message,), {
  'DESCRIPTOR' : _MASTERLOGGING,
  '__module__' : 'yandex.cloud.k8s.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.MasterLogging)
  })
_sym_db.RegisterMessage(MasterLogging)

NetworkPolicy = _reflection.GeneratedProtocolMessageType('NetworkPolicy', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKPOLICY,
  '__module__' : 'yandex.cloud.k8s.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.NetworkPolicy)
  })
_sym_db.RegisterMessage(NetworkPolicy)

KMSProvider = _reflection.GeneratedProtocolMessageType('KMSProvider', (_message.Message,), {
  'DESCRIPTOR' : _KMSPROVIDER,
  '__module__' : 'yandex.cloud.k8s.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.KMSProvider)
  })
_sym_db.RegisterMessage(KMSProvider)

Cilium = _reflection.GeneratedProtocolMessageType('Cilium', (_message.Message,), {
  'DESCRIPTOR' : _CILIUM,
  '__module__' : 'yandex.cloud.k8s.v1.cluster_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.Cilium)
  })
_sym_db.RegisterMessage(Cilium)


DESCRIPTOR._options = None
_CLUSTER_LABELSENTRY._options = None
_CLUSTER.fields_by_name['gateway_ipv4_address']._options = None
_IPALLOCATIONPOLICY.fields_by_name['node_ipv4_cidr_mask_size']._options = None
_MASTERLOGGING.fields_by_name['log_group_id']._options = None
_MASTERLOGGING.fields_by_name['folder_id']._options = None
# @@protoc_insertion_point(module_scope)
