# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/apigateway/websocket/v1/connection_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.serverless.apigateway.websocket.v1 import connection_pb2 as yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/serverless/apigateway/websocket/v1/connection_service.proto',
  package='yandex.cloud.serverless.apigateway.websocket.v1',
  syntax='proto3',
  serialized_options=b'\n3yandex.cloud.api.serverless.apigateway.websocket.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/websocket/v1;websocket',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nHyandex/cloud/serverless/apigateway/websocket/v1/connection_service.proto\x12/yandex.cloud.serverless.apigateway.websocket.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a@yandex/cloud/serverless/apigateway/websocket/v1/connection.proto\";\n\x14GetConnectionRequest\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xfc\x01\n\x17SendToConnectionRequest\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1e\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x42\x10\xe8\xc7\x31\x01\x8a\xc8\x31\x08<=131072\x12_\n\x04type\x18\x03 \x01(\x0e\x32Q.yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest.DataType\";\n\x08\x44\x61taType\x12\x19\n\x15\x44\x41TA_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x42INARY\x10\x01\x12\x08\n\x04TEXT\x10\x02\"\x1a\n\x18SendToConnectionResponse\"8\n\x11\x44isconnectRequest\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x14\n\x12\x44isconnectResponse2\x9a\x05\n\x11\x43onnectionService\x12\xc8\x01\n\x03Get\x12\x45.yandex.cloud.serverless.apigateway.websocket.v1.GetConnectionRequest\x1a;.yandex.cloud.serverless.apigateway.websocket.v1.Connection\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/apigateways/websocket/v1/connections/{connection_id}\x12\xe2\x01\n\x04Send\x12H.yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest\x1aI.yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionResponse\"E\x82\xd3\xe4\x93\x02?\":/apigateways/websocket/v1/connections/{connection_id}:send:\x01*\x12\xd4\x01\n\nDisconnect\x12\x42.yandex.cloud.serverless.apigateway.websocket.v1.DisconnectRequest\x1a\x43.yandex.cloud.serverless.apigateway.websocket.v1.DisconnectResponse\"=\x82\xd3\xe4\x93\x02\x37*5/apigateways/websocket/v1/connections/{connection_id}B\x94\x01\n3yandex.cloud.api.serverless.apigateway.websocket.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/websocket/v1;websocketb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__pb2.DESCRIPTOR,])



_SENDTOCONNECTIONREQUEST_DATATYPE = _descriptor.EnumDescriptor(
  name='DataType',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest.DataType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BINARY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=507,
  serialized_end=566,
)
_sym_db.RegisterEnumDescriptor(_SENDTOCONNECTIONREQUEST_DATATYPE)


_GETCONNECTIONREQUEST = _descriptor.Descriptor(
  name='GetConnectionRequest',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.GetConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='yandex.cloud.serverless.apigateway.websocket.v1.GetConnectionRequest.connection_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=311,
)


_SENDTOCONNECTIONREQUEST = _descriptor.Descriptor(
  name='SendToConnectionRequest',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest.connection_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\010<=131072', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SENDTOCONNECTIONREQUEST_DATATYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=566,
)


_SENDTOCONNECTIONRESPONSE = _descriptor.Descriptor(
  name='SendToConnectionResponse',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=594,
)


_DISCONNECTREQUEST = _descriptor.Descriptor(
  name='DisconnectRequest',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.DisconnectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='yandex.cloud.serverless.apigateway.websocket.v1.DisconnectRequest.connection_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=596,
  serialized_end=652,
)


_DISCONNECTRESPONSE = _descriptor.Descriptor(
  name='DisconnectResponse',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.DisconnectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=654,
  serialized_end=674,
)

_SENDTOCONNECTIONREQUEST.fields_by_name['type'].enum_type = _SENDTOCONNECTIONREQUEST_DATATYPE
_SENDTOCONNECTIONREQUEST_DATATYPE.containing_type = _SENDTOCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['GetConnectionRequest'] = _GETCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['SendToConnectionRequest'] = _SENDTOCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['SendToConnectionResponse'] = _SENDTOCONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['DisconnectRequest'] = _DISCONNECTREQUEST
DESCRIPTOR.message_types_by_name['DisconnectResponse'] = _DISCONNECTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetConnectionRequest = _reflection.GeneratedProtocolMessageType('GetConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONNECTIONREQUEST,
  '__module__' : 'yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.websocket.v1.GetConnectionRequest)
  })
_sym_db.RegisterMessage(GetConnectionRequest)

SendToConnectionRequest = _reflection.GeneratedProtocolMessageType('SendToConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDTOCONNECTIONREQUEST,
  '__module__' : 'yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest)
  })
_sym_db.RegisterMessage(SendToConnectionRequest)

SendToConnectionResponse = _reflection.GeneratedProtocolMessageType('SendToConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDTOCONNECTIONRESPONSE,
  '__module__' : 'yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionResponse)
  })
_sym_db.RegisterMessage(SendToConnectionResponse)

DisconnectRequest = _reflection.GeneratedProtocolMessageType('DisconnectRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTREQUEST,
  '__module__' : 'yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.websocket.v1.DisconnectRequest)
  })
_sym_db.RegisterMessage(DisconnectRequest)

DisconnectResponse = _reflection.GeneratedProtocolMessageType('DisconnectResponse', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTRESPONSE,
  '__module__' : 'yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.websocket.v1.DisconnectResponse)
  })
_sym_db.RegisterMessage(DisconnectResponse)


DESCRIPTOR._options = None
_GETCONNECTIONREQUEST.fields_by_name['connection_id']._options = None
_SENDTOCONNECTIONREQUEST.fields_by_name['connection_id']._options = None
_SENDTOCONNECTIONREQUEST.fields_by_name['data']._options = None
_DISCONNECTREQUEST.fields_by_name['connection_id']._options = None

_CONNECTIONSERVICE = _descriptor.ServiceDescriptor(
  name='ConnectionService',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=677,
  serialized_end=1343,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService.Get',
    index=0,
    containing_service=None,
    input_type=_GETCONNECTIONREQUEST,
    output_type=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__pb2._CONNECTION,
    serialized_options=b'\202\323\344\223\0027\0225/apigateways/websocket/v1/connections/{connection_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Send',
    full_name='yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService.Send',
    index=1,
    containing_service=None,
    input_type=_SENDTOCONNECTIONREQUEST,
    output_type=_SENDTOCONNECTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002?\":/apigateways/websocket/v1/connections/{connection_id}:send:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Disconnect',
    full_name='yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService.Disconnect',
    index=2,
    containing_service=None,
    input_type=_DISCONNECTREQUEST,
    output_type=_DISCONNECTRESPONSE,
    serialized_options=b'\202\323\344\223\0027*5/apigateways/websocket/v1/connections/{connection_id}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONNECTIONSERVICE)

DESCRIPTOR.services_by_name['ConnectionService'] = _CONNECTIONSERVICE

# @@protoc_insertion_point(module_scope)
