# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mongodb/v1/config/mongodb4_2.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/mongodb/v1/config/mongodb4_2.proto',
  package='yandex.cloud.mdb.mongodb.v1.config',
  syntax='proto3',
  serialized_options=b'\n&yandex.cloud.api.mdb.mongodb.v1.configZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3yandex/cloud/mdb/mongodb/v1/config/mongodb4_2.proto\x12\"yandex.cloud.mdb.mongodb.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xfb\n\n\x0fMongodConfig4_2\x12L\n\x07storage\x18\x01 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage\x12\x63\n\x13operation_profiling\x18\x02 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling\x12H\n\x03net\x18\x03 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Network\x1a\xa3\x06\n\x07Storage\x12[\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger\x12T\n\x07journal\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.Journal\x1a\x98\x04\n\nWiredTiger\x12j\n\rengine_config\x18\x01 \x01(\x0b\x32S.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.EngineConfig\x12r\n\x11\x63ollection_config\x18\x02 \x01(\x0b\x32W.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.CollectionConfig\x1a\x43\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xe4\x01\n\x10\x43ollectionConfig\x12|\n\x10\x62lock_compressor\x18\x01 \x01(\x0e\x32\x62.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.CollectionConfig.Compressor\"R\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\n\n\x06SNAPPY\x10\x02\x12\x08\n\x04ZLIB\x10\x03\x12\x08\n\x04ZSTD\x10\x04\x1aJ\n\x07Journal\x12?\n\x0f\x63ommit_interval\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x31-500\x1a\xec\x01\n\x12OperationProfiling\x12Y\n\x04mode\x18\x01 \x01(\x0e\x32K.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\"\x8c\x07\n\x11MongoCfgConfig4_2\x12N\n\x07storage\x18\x01 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage\x12\x65\n\x13operation_profiling\x18\x02 \x01(\x0b\x32H.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling\x12J\n\x03net\x18\x03 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Network\x1a\xaa\x02\n\x07Storage\x12]\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32H.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger\x1a\xbf\x01\n\nWiredTiger\x12l\n\rengine_config\x18\x01 \x01(\x0b\x32U.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger.EngineConfig\x1a\x43\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xee\x01\n\x12OperationProfiling\x12[\n\x04mode\x18\x01 \x01(\x0e\x32M.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\"\xb3\x01\n\x0fMongosConfig4_2\x12H\n\x03net\x18\x01 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2.Network\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\"\xfa\x01\n\x12MongodConfigSet4_2\x12M\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2\x12H\n\x0buser_config\x18\x02 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2\x12K\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2\"\x82\x02\n\x14MongoCfgConfigSet4_2\x12O\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2\x12J\n\x0buser_config\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2\x12M\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2\"\xfa\x01\n\x12MongosConfigSet4_2\x12M\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2\x12H\n\x0buser_config\x18\x02 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2\x12K\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2Bx\n&yandex.cloud.api.mdb.mongodb.v1.configZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodbb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR = _descriptor.EnumDescriptor(
  name='Compressor',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.CollectionConfig.Compressor',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPRESSOR_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNAPPY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ZLIB', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ZSTD', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1073,
  serialized_end=1155,
)
_sym_db.RegisterEnumDescriptor(_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR)

_MONGODCONFIG4_2_OPERATIONPROFILING_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OFF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLOW_OP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1411,
  serialized_end=1470,
)
_sym_db.RegisterEnumDescriptor(_MONGODCONFIG4_2_OPERATIONPROFILING_MODE)

_MONGOCFGCONFIG4_2_OPERATIONPROFILING_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OFF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLOW_OP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1411,
  serialized_end=1470,
)
_sym_db.RegisterEnumDescriptor(_MONGOCFGCONFIG4_2_OPERATIONPROFILING_MODE)


_MONGODCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG = _descriptor.Descriptor(
  name='EngineConfig',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.EngineConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cache_size_gb', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.EngineConfig.cache_size_gb', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=924,
)

_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG = _descriptor.Descriptor(
  name='CollectionConfig',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.CollectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_compressor', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.CollectionConfig.block_compressor', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=927,
  serialized_end=1155,
)

_MONGODCONFIG4_2_STORAGE_WIREDTIGER = _descriptor.Descriptor(
  name='WiredTiger',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='engine_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.engine_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collection_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.collection_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG, _MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=619,
  serialized_end=1155,
)

_MONGODCONFIG4_2_STORAGE_JOURNAL = _descriptor.Descriptor(
  name='Journal',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.Journal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit_interval', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.Journal.commit_interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0051-500', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1157,
  serialized_end=1231,
)

_MONGODCONFIG4_2_STORAGE = _descriptor.Descriptor(
  name='Storage',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wired_tiger', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.wired_tiger', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='journal', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.journal', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODCONFIG4_2_STORAGE_WIREDTIGER, _MONGODCONFIG4_2_STORAGE_JOURNAL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=1231,
)

_MONGODCONFIG4_2_OPERATIONPROFILING = _descriptor.Descriptor(
  name='OperationProfiling',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slow_op_threshold', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling.slow_op_threshold', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MONGODCONFIG4_2_OPERATIONPROFILING_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1234,
  serialized_end=1470,
)

_MONGODCONFIG4_2_NETWORK = _descriptor.Descriptor(
  name='Network',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Network',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_incoming_connections', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Network.max_incoming_connections', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\01010-16384', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1472,
  serialized_end=1558,
)

_MONGODCONFIG4_2 = _descriptor.Descriptor(
  name='MongodConfig4_2',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.storage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_profiling', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.operation_profiling', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='net', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.net', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODCONFIG4_2_STORAGE, _MONGODCONFIG4_2_OPERATIONPROFILING, _MONGODCONFIG4_2_NETWORK, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=1558,
)


_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG = _descriptor.Descriptor(
  name='EngineConfig',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger.EngineConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cache_size_gb', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger.EngineConfig.cache_size_gb', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=924,
)

_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER = _descriptor.Descriptor(
  name='WiredTiger',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='engine_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger.engine_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1949,
  serialized_end=2140,
)

_MONGOCFGCONFIG4_2_STORAGE = _descriptor.Descriptor(
  name='Storage',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wired_tiger', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.wired_tiger', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1842,
  serialized_end=2140,
)

_MONGOCFGCONFIG4_2_OPERATIONPROFILING = _descriptor.Descriptor(
  name='OperationProfiling',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slow_op_threshold', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling.slow_op_threshold', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MONGOCFGCONFIG4_2_OPERATIONPROFILING_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2143,
  serialized_end=2381,
)

_MONGOCFGCONFIG4_2_NETWORK = _descriptor.Descriptor(
  name='Network',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Network',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_incoming_connections', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Network.max_incoming_connections', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\01010-16384', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1472,
  serialized_end=1558,
)

_MONGOCFGCONFIG4_2 = _descriptor.Descriptor(
  name='MongoCfgConfig4_2',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.storage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_profiling', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.operation_profiling', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='net', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.net', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGOCFGCONFIG4_2_STORAGE, _MONGOCFGCONFIG4_2_OPERATIONPROFILING, _MONGOCFGCONFIG4_2_NETWORK, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1561,
  serialized_end=2469,
)


_MONGOSCONFIG4_2_NETWORK = _descriptor.Descriptor(
  name='Network',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2.Network',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_incoming_connections', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2.Network.max_incoming_connections', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\01010-16384', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1472,
  serialized_end=1558,
)

_MONGOSCONFIG4_2 = _descriptor.Descriptor(
  name='MongosConfig4_2',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='net', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2.net', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGOSCONFIG4_2_NETWORK, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2472,
  serialized_end=2651,
)


_MONGODCONFIGSET4_2 = _descriptor.Descriptor(
  name='MongodConfigSet4_2',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet4_2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet4_2.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet4_2.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet4_2.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2654,
  serialized_end=2904,
)


_MONGOCFGCONFIGSET4_2 = _descriptor.Descriptor(
  name='MongoCfgConfigSet4_2',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_2.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_2.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_2.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2907,
  serialized_end=3165,
)


_MONGOSCONFIGSET4_2 = _descriptor.Descriptor(
  name='MongosConfigSet4_2',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_2.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_2.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_2.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3168,
  serialized_end=3418,
)

_MONGODCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG.fields_by_name['cache_size_gb'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_MONGODCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG.containing_type = _MONGODCONFIG4_2_STORAGE_WIREDTIGER
_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG.fields_by_name['block_compressor'].enum_type = _MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR
_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG.containing_type = _MONGODCONFIG4_2_STORAGE_WIREDTIGER
_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR.containing_type = _MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG
_MONGODCONFIG4_2_STORAGE_WIREDTIGER.fields_by_name['engine_config'].message_type = _MONGODCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG
_MONGODCONFIG4_2_STORAGE_WIREDTIGER.fields_by_name['collection_config'].message_type = _MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG
_MONGODCONFIG4_2_STORAGE_WIREDTIGER.containing_type = _MONGODCONFIG4_2_STORAGE
_MONGODCONFIG4_2_STORAGE_JOURNAL.fields_by_name['commit_interval'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGODCONFIG4_2_STORAGE_JOURNAL.containing_type = _MONGODCONFIG4_2_STORAGE
_MONGODCONFIG4_2_STORAGE.fields_by_name['wired_tiger'].message_type = _MONGODCONFIG4_2_STORAGE_WIREDTIGER
_MONGODCONFIG4_2_STORAGE.fields_by_name['journal'].message_type = _MONGODCONFIG4_2_STORAGE_JOURNAL
_MONGODCONFIG4_2_STORAGE.containing_type = _MONGODCONFIG4_2
_MONGODCONFIG4_2_OPERATIONPROFILING.fields_by_name['mode'].enum_type = _MONGODCONFIG4_2_OPERATIONPROFILING_MODE
_MONGODCONFIG4_2_OPERATIONPROFILING.fields_by_name['slow_op_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGODCONFIG4_2_OPERATIONPROFILING.containing_type = _MONGODCONFIG4_2
_MONGODCONFIG4_2_OPERATIONPROFILING_MODE.containing_type = _MONGODCONFIG4_2_OPERATIONPROFILING
_MONGODCONFIG4_2_NETWORK.fields_by_name['max_incoming_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGODCONFIG4_2_NETWORK.containing_type = _MONGODCONFIG4_2
_MONGODCONFIG4_2.fields_by_name['storage'].message_type = _MONGODCONFIG4_2_STORAGE
_MONGODCONFIG4_2.fields_by_name['operation_profiling'].message_type = _MONGODCONFIG4_2_OPERATIONPROFILING
_MONGODCONFIG4_2.fields_by_name['net'].message_type = _MONGODCONFIG4_2_NETWORK
_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG.fields_by_name['cache_size_gb'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG.containing_type = _MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER
_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER.fields_by_name['engine_config'].message_type = _MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG
_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER.containing_type = _MONGOCFGCONFIG4_2_STORAGE
_MONGOCFGCONFIG4_2_STORAGE.fields_by_name['wired_tiger'].message_type = _MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER
_MONGOCFGCONFIG4_2_STORAGE.containing_type = _MONGOCFGCONFIG4_2
_MONGOCFGCONFIG4_2_OPERATIONPROFILING.fields_by_name['mode'].enum_type = _MONGOCFGCONFIG4_2_OPERATIONPROFILING_MODE
_MONGOCFGCONFIG4_2_OPERATIONPROFILING.fields_by_name['slow_op_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGOCFGCONFIG4_2_OPERATIONPROFILING.containing_type = _MONGOCFGCONFIG4_2
_MONGOCFGCONFIG4_2_OPERATIONPROFILING_MODE.containing_type = _MONGOCFGCONFIG4_2_OPERATIONPROFILING
_MONGOCFGCONFIG4_2_NETWORK.fields_by_name['max_incoming_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGOCFGCONFIG4_2_NETWORK.containing_type = _MONGOCFGCONFIG4_2
_MONGOCFGCONFIG4_2.fields_by_name['storage'].message_type = _MONGOCFGCONFIG4_2_STORAGE
_MONGOCFGCONFIG4_2.fields_by_name['operation_profiling'].message_type = _MONGOCFGCONFIG4_2_OPERATIONPROFILING
_MONGOCFGCONFIG4_2.fields_by_name['net'].message_type = _MONGOCFGCONFIG4_2_NETWORK
_MONGOSCONFIG4_2_NETWORK.fields_by_name['max_incoming_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGOSCONFIG4_2_NETWORK.containing_type = _MONGOSCONFIG4_2
_MONGOSCONFIG4_2.fields_by_name['net'].message_type = _MONGOSCONFIG4_2_NETWORK
_MONGODCONFIGSET4_2.fields_by_name['effective_config'].message_type = _MONGODCONFIG4_2
_MONGODCONFIGSET4_2.fields_by_name['user_config'].message_type = _MONGODCONFIG4_2
_MONGODCONFIGSET4_2.fields_by_name['default_config'].message_type = _MONGODCONFIG4_2
_MONGOCFGCONFIGSET4_2.fields_by_name['effective_config'].message_type = _MONGOCFGCONFIG4_2
_MONGOCFGCONFIGSET4_2.fields_by_name['user_config'].message_type = _MONGOCFGCONFIG4_2
_MONGOCFGCONFIGSET4_2.fields_by_name['default_config'].message_type = _MONGOCFGCONFIG4_2
_MONGOSCONFIGSET4_2.fields_by_name['effective_config'].message_type = _MONGOSCONFIG4_2
_MONGOSCONFIGSET4_2.fields_by_name['user_config'].message_type = _MONGOSCONFIG4_2
_MONGOSCONFIGSET4_2.fields_by_name['default_config'].message_type = _MONGOSCONFIG4_2
DESCRIPTOR.message_types_by_name['MongodConfig4_2'] = _MONGODCONFIG4_2
DESCRIPTOR.message_types_by_name['MongoCfgConfig4_2'] = _MONGOCFGCONFIG4_2
DESCRIPTOR.message_types_by_name['MongosConfig4_2'] = _MONGOSCONFIG4_2
DESCRIPTOR.message_types_by_name['MongodConfigSet4_2'] = _MONGODCONFIGSET4_2
DESCRIPTOR.message_types_by_name['MongoCfgConfigSet4_2'] = _MONGOCFGCONFIGSET4_2
DESCRIPTOR.message_types_by_name['MongosConfigSet4_2'] = _MONGOSCONFIGSET4_2
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MongodConfig4_2 = _reflection.GeneratedProtocolMessageType('MongodConfig4_2', (_message.Message,), {

  'Storage' : _reflection.GeneratedProtocolMessageType('Storage', (_message.Message,), {

    'WiredTiger' : _reflection.GeneratedProtocolMessageType('WiredTiger', (_message.Message,), {

      'EngineConfig' : _reflection.GeneratedProtocolMessageType('EngineConfig', (_message.Message,), {
        'DESCRIPTOR' : _MONGODCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG,
        '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
        # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.EngineConfig)
        })
      ,

      'CollectionConfig' : _reflection.GeneratedProtocolMessageType('CollectionConfig', (_message.Message,), {
        'DESCRIPTOR' : _MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG,
        '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
        # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.CollectionConfig)
        })
      ,
      'DESCRIPTOR' : _MONGODCONFIG4_2_STORAGE_WIREDTIGER,
      '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger)
      })
    ,

    'Journal' : _reflection.GeneratedProtocolMessageType('Journal', (_message.Message,), {
      'DESCRIPTOR' : _MONGODCONFIG4_2_STORAGE_JOURNAL,
      '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.Journal)
      })
    ,
    'DESCRIPTOR' : _MONGODCONFIG4_2_STORAGE,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage)
    })
  ,

  'OperationProfiling' : _reflection.GeneratedProtocolMessageType('OperationProfiling', (_message.Message,), {
    'DESCRIPTOR' : _MONGODCONFIG4_2_OPERATIONPROFILING,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling)
    })
  ,

  'Network' : _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), {
    'DESCRIPTOR' : _MONGODCONFIG4_2_NETWORK,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Network)
    })
  ,
  'DESCRIPTOR' : _MONGODCONFIG4_2,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2)
  })
_sym_db.RegisterMessage(MongodConfig4_2)
_sym_db.RegisterMessage(MongodConfig4_2.Storage)
_sym_db.RegisterMessage(MongodConfig4_2.Storage.WiredTiger)
_sym_db.RegisterMessage(MongodConfig4_2.Storage.WiredTiger.EngineConfig)
_sym_db.RegisterMessage(MongodConfig4_2.Storage.WiredTiger.CollectionConfig)
_sym_db.RegisterMessage(MongodConfig4_2.Storage.Journal)
_sym_db.RegisterMessage(MongodConfig4_2.OperationProfiling)
_sym_db.RegisterMessage(MongodConfig4_2.Network)

MongoCfgConfig4_2 = _reflection.GeneratedProtocolMessageType('MongoCfgConfig4_2', (_message.Message,), {

  'Storage' : _reflection.GeneratedProtocolMessageType('Storage', (_message.Message,), {

    'WiredTiger' : _reflection.GeneratedProtocolMessageType('WiredTiger', (_message.Message,), {

      'EngineConfig' : _reflection.GeneratedProtocolMessageType('EngineConfig', (_message.Message,), {
        'DESCRIPTOR' : _MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG,
        '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
        # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger.EngineConfig)
        })
      ,
      'DESCRIPTOR' : _MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER,
      '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger)
      })
    ,
    'DESCRIPTOR' : _MONGOCFGCONFIG4_2_STORAGE,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage)
    })
  ,

  'OperationProfiling' : _reflection.GeneratedProtocolMessageType('OperationProfiling', (_message.Message,), {
    'DESCRIPTOR' : _MONGOCFGCONFIG4_2_OPERATIONPROFILING,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling)
    })
  ,

  'Network' : _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), {
    'DESCRIPTOR' : _MONGOCFGCONFIG4_2_NETWORK,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Network)
    })
  ,
  'DESCRIPTOR' : _MONGOCFGCONFIG4_2,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2)
  })
_sym_db.RegisterMessage(MongoCfgConfig4_2)
_sym_db.RegisterMessage(MongoCfgConfig4_2.Storage)
_sym_db.RegisterMessage(MongoCfgConfig4_2.Storage.WiredTiger)
_sym_db.RegisterMessage(MongoCfgConfig4_2.Storage.WiredTiger.EngineConfig)
_sym_db.RegisterMessage(MongoCfgConfig4_2.OperationProfiling)
_sym_db.RegisterMessage(MongoCfgConfig4_2.Network)

MongosConfig4_2 = _reflection.GeneratedProtocolMessageType('MongosConfig4_2', (_message.Message,), {

  'Network' : _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), {
    'DESCRIPTOR' : _MONGOSCONFIG4_2_NETWORK,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2.Network)
    })
  ,
  'DESCRIPTOR' : _MONGOSCONFIG4_2,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2)
  })
_sym_db.RegisterMessage(MongosConfig4_2)
_sym_db.RegisterMessage(MongosConfig4_2.Network)

MongodConfigSet4_2 = _reflection.GeneratedProtocolMessageType('MongodConfigSet4_2', (_message.Message,), {
  'DESCRIPTOR' : _MONGODCONFIGSET4_2,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet4_2)
  })
_sym_db.RegisterMessage(MongodConfigSet4_2)

MongoCfgConfigSet4_2 = _reflection.GeneratedProtocolMessageType('MongoCfgConfigSet4_2', (_message.Message,), {
  'DESCRIPTOR' : _MONGOCFGCONFIGSET4_2,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_2)
  })
_sym_db.RegisterMessage(MongoCfgConfigSet4_2)

MongosConfigSet4_2 = _reflection.GeneratedProtocolMessageType('MongosConfigSet4_2', (_message.Message,), {
  'DESCRIPTOR' : _MONGOSCONFIGSET4_2,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_2)
  })
_sym_db.RegisterMessage(MongosConfigSet4_2)


DESCRIPTOR._options = None
_MONGODCONFIG4_2_STORAGE_JOURNAL.fields_by_name['commit_interval']._options = None
_MONGODCONFIG4_2_OPERATIONPROFILING.fields_by_name['slow_op_threshold']._options = None
_MONGODCONFIG4_2_NETWORK.fields_by_name['max_incoming_connections']._options = None
_MONGOCFGCONFIG4_2_OPERATIONPROFILING.fields_by_name['slow_op_threshold']._options = None
_MONGOCFGCONFIG4_2_NETWORK.fields_by_name['max_incoming_connections']._options = None
_MONGOSCONFIG4_2_NETWORK.fields_by_name['max_incoming_connections']._options = None
# @@protoc_insertion_point(module_scope)
